@@ -1,15 +1,6 @@
 from __future__ import annotations
 
-from typing import (
-    TYPE_CHECKING,
-    Any,
-    Generic,
-    Iterable,
-    Iterator,
-    Mapping,
-    Protocol,
-    Sequence,
-)
+from typing import TYPE_CHECKING, Any, Generic, Protocol
 
 from narwhals._compliant.any_namespace import (
     CatNamespace,
@@ -25,7 +16,8 @@ from narwhals._compliant.typing import (
     NativeSeriesT_co,
 )
 from narwhals._translate import FromIterable, FromNative, NumpyConvertible, ToNarwhals
-from narwhals.utils import (
+from narwhals._typing_compat import assert_never
+from narwhals._utils import (
     _StoresCompliant,
     _StoresNative,
     is_compliant_series,
@@ -34,6 +26,7 @@ from narwhals.utils import (
 )
 
 if TYPE_CHECKING:
+    from collections.abc import Iterable, Iterator, Mapping, Sequence
     from types import ModuleType
 
     import pandas as pd
@@ -44,12 +37,14 @@ if TYPE_CHECKING:
     from narwhals._compliant.dataframe import CompliantDataFrame
     from narwhals._compliant.expr import CompliantExpr, EagerExpr
     from narwhals._compliant.namespace import CompliantNamespace, EagerNamespace
+    from narwhals._utils import Implementation, Version, _FullContext
     from narwhals.dtypes import DType
     from narwhals.series import Series
     from narwhals.typing import (
         ClosedInterval,
         FillNullStrategy,
         Into1DArray,
+        IntoDType,
         MultiIndexSelector,
         NonNestedLiteral,
         NumericLiteral,
@@ -60,7 +55,6 @@ if TYPE_CHECKING:
         _1DArray,
         _SliceIndex,
     )
-    from narwhals.utils import Implementation, Version, _FullContext
 
 __all__ = ["CompliantSeries", "EagerSeries"]
 
@@ -109,7 +103,7 @@ class CompliantSeries(
         *,
         context: _FullContext,
         name: str = "",
-        dtype: DType | type[DType] | None = None,
+        dtype: IntoDType | None = None,
     ) -> Self: ...
     def to_narwhals(self) -> Series[NativeSeriesT]:
         return self._version.series(self, level="full")
@@ -148,7 +142,7 @@ class CompliantSeries(
     def arg_max(self) -> int: ...
     def arg_min(self) -> int: ...
     def arg_true(self) -> Self: ...
-    def cast(self, dtype: DType | type[DType]) -> Self: ...
+    def cast(self, dtype: IntoDType) -> Self: ...
     def clip(
         self,
         lower_bound: Self | NumericLiteral | TemporalLiteral | None,
@@ -173,6 +167,8 @@ class CompliantSeries(
         min_samples: int,
         ignore_nulls: bool,
     ) -> Self: ...
+    def exp(self) -> Self: ...
+    def sqrt(self) -> Self: ...
     def fill_null(
         self,
         value: Self | NonNestedLiteral,
@@ -202,6 +198,7 @@ class CompliantSeries(
     def is_sorted(self, *, descending: bool) -> bool: ...
     def is_unique(self) -> Self: ...
     def item(self, index: int | None) -> Any: ...
+    def kurtosis(self) -> float | None: ...
     def len(self) -> int: ...
     def log(self, base: float) -> Self: ...
     def max(self) -> Any: ...
@@ -220,7 +217,7 @@ class CompliantSeries(
         old: Sequence[Any] | Mapping[Any, Any],
         new: Sequence[Any],
         *,
-        return_dtype: DType | type[DType] | None,
+        return_dtype: IntoDType | None,
     ) -> Self: ...
     def rolling_mean(
         self, window_size: int, *, min_samples: int, center: bool
@@ -284,6 +281,24 @@ class EagerSeries(CompliantSeries[NativeSeriesT], Protocol[NativeSeriesT]):
     _version: Version
     _broadcast: bool
 
+    @classmethod
+    def _align_full_broadcast(cls, *series: Self) -> Sequence[Self]:
+        """Ensure all of `series` have the same length (and index if `pandas`).
+
+        Scalars get broadcasted to the full length of the longest Series.
+
+        This is useful when you need to construct a full Series anyway, such as:
+
+            DataFrame.select(...)
+
+        It should not be used in binary operations, such as:
+
+            nw.col("a") - nw.col("a").mean()
+
+        because then it's more efficient to extract the right-hand-side's single element as a scalar.
+        """
+        ...
+
     def _from_scalar(self, value: Any) -> Self:
         return self.from_iterable([value], name=self.name, context=self)
 
@@ -316,9 +331,8 @@ class EagerSeries(CompliantSeries[NativeSeriesT], Protocol[NativeSeriesT]):
             return self._gather(item.native)
         elif is_sized_multi_index_selector(item):
             return self._gather(item)
-        else:  # pragma: no cover
-            msg = f"Unreachable code, got unexpected type: {type(item)}"
-            raise AssertionError(msg)
+        else:
+            assert_never(item)
 
     @property
     def str(self) -> EagerSeriesStringNamespace[Self, NativeSeriesT]: ...
