@@ -5,8 +5,9 @@ from __future__ import annotations
 
 from enum import Enum, auto
 from itertools import chain
-from typing import TYPE_CHECKING, Any, Literal, Sequence, TypeVar, cast
+from typing import TYPE_CHECKING, Any, Literal, TypeVar, cast
 
+from narwhals._utils import is_compliant_expr
 from narwhals.dependencies import is_narwhals_series, is_numpy_array
 from narwhals.exceptions import (
     InvalidOperationError,
@@ -14,9 +15,10 @@ from narwhals.exceptions import (
     MultiOutputExpressionError,
     ShapeError,
 )
-from narwhals.utils import is_compliant_expr
 
 if TYPE_CHECKING:
+    from collections.abc import Sequence
+
     from typing_extensions import Never, TypeIs
 
     from narwhals._compliant import CompliantExpr, CompliantFrameT
