@@ -3,50 +3,46 @@ from __future__ import annotations
 import warnings
 from functools import reduce
 from operator import and_
-from typing import TYPE_CHECKING
-from typing import Any
-from typing import Iterator
-from typing import Mapping
-from typing import Sequence
+from typing import TYPE_CHECKING, Any
 
 from narwhals._namespace import is_native_spark_like
-from narwhals._spark_like.utils import evaluate_exprs
-from narwhals._spark_like.utils import import_functions
-from narwhals._spark_like.utils import import_native_dtypes
-from narwhals._spark_like.utils import import_window
-from narwhals._spark_like.utils import native_to_narwhals_dtype
+from narwhals._spark_like.utils import (
+    evaluate_exprs,
+    import_functions,
+    import_native_dtypes,
+    import_window,
+    native_to_narwhals_dtype,
+)
+from narwhals._utils import (
+    Implementation,
+    find_stacklevel,
+    generate_temporary_column_name,
+    not_implemented,
+    parse_columns_to_drop,
+    parse_version,
+    validate_backend_version,
+)
 from narwhals.exceptions import InvalidOperationError
 from narwhals.typing import CompliantLazyFrame
-from narwhals.utils import Implementation
-from narwhals.utils import check_column_exists
-from narwhals.utils import find_stacklevel
-from narwhals.utils import generate_temporary_column_name
-from narwhals.utils import not_implemented
-from narwhals.utils import parse_columns_to_drop
-from narwhals.utils import parse_version
-from narwhals.utils import validate_backend_version
 
 if TYPE_CHECKING:
+    from collections.abc import Iterator, Mapping, Sequence
     from types import ModuleType
 
     import pyarrow as pa
     from sqlframe.base.column import Column
     from sqlframe.base.dataframe import BaseDataFrame
     from sqlframe.base.window import Window
-    from typing_extensions import Self
-    from typing_extensions import TypeAlias
-    from typing_extensions import TypeIs
+    from typing_extensions import Self, TypeAlias, TypeIs
 
     from narwhals._compliant.typing import CompliantDataFrameAny
     from narwhals._spark_like.expr import SparkLikeExpr
     from narwhals._spark_like.group_by import SparkLikeLazyGroupBy
     from narwhals._spark_like.namespace import SparkLikeNamespace
+    from narwhals._utils import Version, _FullContext
     from narwhals.dataframe import LazyFrame
     from narwhals.dtypes import DType
-    from narwhals.typing import JoinStrategy
-    from narwhals.typing import LazyUniqueKeepStrategy
-    from narwhals.utils import Version
-    from narwhals.utils import _FullContext
+    from narwhals.typing import JoinStrategy, LazyUniqueKeepStrategy
 
     SQLFrameDataFrame = BaseDataFrame[Any, Any, Any, Any, Any]
 
@@ -259,19 +255,13 @@ class SparkLikeLazyFrame(
     def simple_select(self, *column_names: str) -> Self:
         return self._with_native(self.native.select(*column_names))
 
-    def aggregate(
-        self,
-        *exprs: SparkLikeExpr,
-    ) -> Self:
+    def aggregate(self, *exprs: SparkLikeExpr) -> Self:
         new_columns = evaluate_exprs(self, *exprs)
 
         new_columns_list = [col.alias(col_name) for col_name, col in new_columns]
         return self._with_native(self.native.agg(*new_columns_list))
 
-    def select(
-        self,
-        *exprs: SparkLikeExpr,
-    ) -> Self:
+    def select(self, *exprs: SparkLikeExpr) -> Self:
         new_columns = evaluate_exprs(self, *exprs)
         new_columns_list = [col.alias(col_name) for (col_name, col) in new_columns]
         return self._with_native(self.native.select(*new_columns_list))
@@ -291,9 +281,10 @@ class SparkLikeLazyFrame(
         if self._cached_schema is None:
             self._cached_schema = {
                 field.name: native_to_narwhals_dtype(
-                    dtype=field.dataType,
-                    version=self._version,
-                    spark_types=self._native_dtypes,
+                    field.dataType,
+                    self._version,
+                    self._native_dtypes,
+                    self.native.sparkSession,
                 )
                 for field in self.native.schema
             }
@@ -303,9 +294,7 @@ class SparkLikeLazyFrame(
         return self.schema
 
     def drop(self, columns: Sequence[str], *, strict: bool) -> Self:
-        columns_to_drop = parse_columns_to_drop(
-            compliant_frame=self, columns=columns, strict=strict
-        )
+        columns_to_drop = parse_columns_to_drop(self, columns, strict=strict)
         return self._with_native(self.native.drop(*columns_to_drop))
 
     def head(self, n: int) -> Self:
@@ -318,12 +307,7 @@ class SparkLikeLazyFrame(
 
         return SparkLikeLazyGroupBy(self, keys, drop_null_keys=drop_null_keys)
 
-    def sort(
-        self,
-        *by: str,
-        descending: bool | Sequence[bool],
-        nulls_last: bool,
-    ) -> Self:
+    def sort(self, *by: str, descending: bool | Sequence[bool], nulls_last: bool) -> Self:
         if isinstance(descending, bool):
             descending = [descending] * len(by)
 
@@ -358,7 +342,8 @@ class SparkLikeLazyFrame(
     def unique(
         self, subset: Sequence[str] | None, *, keep: LazyUniqueKeepStrategy
     ) -> Self:
-        check_column_exists(self.columns, subset)
+        if subset and (error := self._check_columns_exist(subset)):
+            raise error
         subset = list(subset) if subset else None
         if keep == "none":
             tmp = generate_temporary_column_name(8, self.columns)
@@ -499,7 +484,7 @@ class SparkLikeLazyFrame(
                             for col_name in column_names
                         ]
                     )
-                ),
+                )
             )
         else:  # pragma: no cover
             msg = "Unreachable code, please report an issue at https://github.com/narwhals-dev/narwhals/issues"
@@ -537,6 +522,15 @@ class SparkLikeLazyFrame(
             unpivoted_native_frame = unpivoted_native_frame.drop(*ids)
         return self._with_native(unpivoted_native_frame)
 
+    def with_row_index(self, name: str, order_by: Sequence[str]) -> Self:
+        row_index_expr = (
+            self._F.row_number().over(
+                self._Window.partitionBy(self._F.lit(1)).orderBy(*order_by)
+            )
+            - 1
+        ).alias(name)
+        return self._with_native(self.native.select(row_index_expr, *self.columns))
+
     gather_every = not_implemented.deprecated(
         "`LazyFrame.gather_every` is deprecated and will be removed in a future version."
     )
@@ -544,4 +538,3 @@ class SparkLikeLazyFrame(
     tail = not_implemented.deprecated(
         "`LazyFrame.tail` is deprecated and will be removed in a future version."
     )
-    with_row_index = not_implemented()
