@@ -1,15 +1,18 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING
-from typing import Any
-from typing import Callable
-from typing import Generic
-from typing import Iterator
-from typing import Literal
-from typing import Mapping
-from typing import Sequence
-from typing import overload
+import math
+from collections.abc import Iterator, Mapping, Sequence
+from typing import TYPE_CHECKING, Any, Callable, Generic, Literal, overload
 
+from narwhals._utils import (
+    _validate_rolling_arguments,
+    ensure_type,
+    generate_repr,
+    is_compliant_series,
+    is_index_selector,
+    parse_version,
+    supports_arrow_c_stream,
+)
 from narwhals.dependencies import is_numpy_scalar
 from narwhals.dtypes import _validate_dtype
 from narwhals.exceptions import ComputeError
@@ -20,12 +23,6 @@ from narwhals.series_str import SeriesStringNamespace
 from narwhals.series_struct import SeriesStructNamespace
 from narwhals.translate import to_native
 from narwhals.typing import IntoSeriesT
-from narwhals.utils import _validate_rolling_arguments
-from narwhals.utils import generate_repr
-from narwhals.utils import is_compliant_series
-from narwhals.utils import is_index_selector
-from narwhals.utils import parse_version
-from narwhals.utils import supports_arrow_c_stream
 
 if TYPE_CHECKING:
     from types import ModuleType
@@ -36,19 +33,21 @@ if TYPE_CHECKING:
     from typing_extensions import Self
 
     from narwhals._compliant import CompliantSeries
-    from narwhals.dataframe import DataFrame
-    from narwhals.dataframe import MultiIndexSelector
+    from narwhals._utils import Implementation
+    from narwhals.dataframe import DataFrame, MultiIndexSelector
     from narwhals.dtypes import DType
-    from narwhals.typing import ClosedInterval
-    from narwhals.typing import FillNullStrategy
-    from narwhals.typing import NonNestedLiteral
-    from narwhals.typing import NumericLiteral
-    from narwhals.typing import RankMethod
-    from narwhals.typing import RollingInterpolationMethod
-    from narwhals.typing import SingleIndexSelector
-    from narwhals.typing import TemporalLiteral
-    from narwhals.typing import _1DArray
-    from narwhals.utils import Implementation
+    from narwhals.typing import (
+        ClosedInterval,
+        FillNullStrategy,
+        IntoDType,
+        NonNestedLiteral,
+        NumericLiteral,
+        RankMethod,
+        RollingInterpolationMethod,
+        SingleIndexSelector,
+        TemporalLiteral,
+        _1DArray,
+    )
 
 
 class Series(Generic[IntoSeriesT]):
@@ -66,13 +65,9 @@ class Series(Generic[IntoSeriesT]):
             ```
 
         - If the object is a generic sequence (e.g. a list or a tuple of values), you can
-            create a series via [`narwhals.new_series`][]:
+            create a series via [`narwhals.new_series`][], e.g.:
             ```py
-            narwhals.new_series(
-                name=name,
-                values=values,
-                backend=narwhals.get_native_namespace(another_object),
-            )
+            narwhals.new_series(name="price", values=[10.5, 9.4, 1.2], backend="pandas")
             ```
     """
 
@@ -83,10 +78,7 @@ class Series(Generic[IntoSeriesT]):
         return DataFrame
 
     def __init__(
-        self,
-        series: Any,
-        *,
-        level: Literal["full", "lazy", "interchange"],
+        self, series: Any, *, level: Literal["full", "lazy", "interchange"]
     ) -> None:
         self._level: Literal["full", "lazy", "interchange"] = level
         if is_compliant_series(series):
@@ -473,7 +465,7 @@ class Series(Generic[IntoSeriesT]):
             )
         )
 
-    def cast(self, dtype: DType | type[DType]) -> Self:
+    def cast(self, dtype: IntoDType) -> Self:
         """Cast between data types.
 
         Arguments:
@@ -522,10 +514,7 @@ class Series(Generic[IntoSeriesT]):
             │ 2   │
             └─────┘
         """
-        return self._dataframe(
-            self._compliant_series.to_frame(),
-            level=self._level,
-        )
+        return self._dataframe(self._compliant_series.to_frame(), level=self._level)
 
     def to_list(self) -> list[Any]:
         """Convert to list.
@@ -604,6 +593,25 @@ class Series(Generic[IntoSeriesT]):
         """
         return self._compliant_series.skew()
 
+    def kurtosis(self) -> float | None:
+        """Compute the kurtosis (Fisher's definition) without bias correction.
+
+        Kurtosis is the fourth central moment divided by the square of the variance.
+        The Fisher's definition is used where 3.0 is subtracted from the result to give 0.0 for a normal distribution.
+
+        Returns:
+            The kurtosis (Fisher's definition) without bias correction of the column.
+
+        Examples:
+            >>> import polars as pl
+            >>> import narwhals as nw
+            >>>
+            >>> s_native = pl.Series([1, 1, 2, 10, 100])
+            >>> nw.from_native(s_native, series_only=True).kurtosis()
+            0.2106571340718002
+        """
+        return self._compliant_series.kurtosis()
+
     def count(self) -> int:
         """Returns the number of non-null elements in the Series.
 
@@ -623,8 +631,10 @@ class Series(Generic[IntoSeriesT]):
     def any(self) -> bool:
         """Return whether any of the values in the Series are True.
 
+        If there are no non-null elements, the result is `False`.
+
         Notes:
-          Only works on Series of data type Boolean.
+            Only works on Series of data type Boolean.
 
         Returns:
             A boolean indicating if any values in the Series are True.
@@ -642,6 +652,8 @@ class Series(Generic[IntoSeriesT]):
     def all(self) -> bool:
         """Return whether all values in the Series are True.
 
+        If there are no non-null elements, the result is `True`.
+
         Returns:
             A boolean indicating if all values in the Series are True.
 
@@ -716,6 +728,8 @@ class Series(Generic[IntoSeriesT]):
     def sum(self) -> float:
         """Reduce this Series to the sum value.
 
+        If there are no non-null elements, the result is zero.
+
         Returns:
             The sum of all elements in the Series.
 
@@ -1021,6 +1035,8 @@ class Series(Generic[IntoSeriesT]):
             2    4.0
             dtype: float64
         """
+        ensure_type(n, int, param_name="n")
+
         return self._with_compliant(self._compliant_series.shift(n))
 
     def sample(
@@ -1165,7 +1181,7 @@ class Series(Generic[IntoSeriesT]):
         old: Sequence[Any] | Mapping[Any, Any],
         new: Sequence[Any] | None = None,
         *,
-        return_dtype: DType | type[DType] | None = None,
+        return_dtype: IntoDType | None = None,
     ) -> Self:
         """Replace all values by different values.
 
@@ -1174,7 +1190,7 @@ class Series(Generic[IntoSeriesT]):
         Arguments:
             old: Sequence of values to replace. It also accepts a mapping of values to
                 their replacement as syntactic sugar for
-                `replace_all(old=list(mapping.keys()), new=list(mapping.values()))`.
+                `replace_strict(old=list(mapping.keys()), new=list(mapping.values()))`.
             new: Sequence of values to replace by. Length must match the length of `old`.
             return_dtype: The data type of the resulting expression. If set to `None`
                 (default), the data type is determined automatically based on the other
@@ -1189,9 +1205,7 @@ class Series(Generic[IntoSeriesT]):
             >>>
             >>> s_native = pd.Series([3, 0, 1, 2], name="a")
             >>> nw.from_native(s_native, series_only=True).replace_strict(
-            ...     [0, 1, 2, 3],
-            ...     ["zero", "one", "two", "three"],
-            ...     return_dtype=nw.String,
+            ...     [0, 1, 2, 3], ["zero", "one", "two", "three"], return_dtype=nw.String
             ... ).to_native()
             0    three
             1     zero
@@ -1309,9 +1323,11 @@ class Series(Generic[IntoSeriesT]):
             limit: Number of consecutive null values to fill when using the 'forward' or 'backward' strategy.
 
         Notes:
-            pandas handles null values differently from Polars and PyArrow.
-            See [null_handling](../concepts/null_handling.md/)
-            for reference.
+            - pandas handles null values differently from other libraries.
+              See [null_handling](../concepts/null_handling.md/)
+              for reference.
+            - For pandas Series of `object` dtype, `fill_null` will not automatically change the
+              Series' dtype as pandas used to do. Explicitly call `cast` if you want the dtype to change.
 
         Returns:
             A new Series with null values filled according to the specified value or strategy.
@@ -2254,11 +2270,7 @@ class Series(Generic[IntoSeriesT]):
         return self._with_compliant(self._compliant_series.cum_prod(reverse=reverse))
 
     def rolling_sum(
-        self,
-        window_size: int,
-        *,
-        min_samples: int | None = None,
-        center: bool = False,
+        self, window_size: int, *, min_samples: int | None = None, center: bool = False
     ) -> Self:
         """Apply a rolling sum (moving sum) over the values.
 
@@ -2308,11 +2320,7 @@ class Series(Generic[IntoSeriesT]):
         )
 
     def rolling_mean(
-        self,
-        window_size: int,
-        *,
-        min_samples: int | None = None,
-        center: bool = False,
+        self, window_size: int, *, min_samples: int | None = None, center: bool = False
     ) -> Self:
         """Apply a rolling mean (moving mean) over the values.
 
@@ -2594,13 +2602,83 @@ class Series(Generic[IntoSeriesT]):
 
         return self._dataframe(
             self._compliant_series.hist(
-                bins=bins,
-                bin_count=bin_count,
-                include_breakpoint=include_breakpoint,
+                bins=bins, bin_count=bin_count, include_breakpoint=include_breakpoint
             ),
             level=self._level,
         )
 
+    def log(self, base: float = math.e) -> Self:
+        r"""Compute the logarithm to a given base.
+
+        Arguments:
+            base: Given base, defaults to `e`
+
+        Returns:
+            A new series.
+
+        Examples:
+            >>> import pandas as pd
+            >>> import narwhals as nw
+            >>> s_native = pd.Series([1, 2, 4], name="a")
+            >>> s = nw.from_native(s_native, series_only=True)
+            >>> s.log(base=2)
+            ┌───────────────────────┐
+            |    Narwhals Series    |
+            |-----------------------|
+            |0    0.0               |
+            |1    1.0               |
+            |2    2.0               |
+            |Name: a, dtype: float64|
+            └───────────────────────┘
+        """
+        return self._with_compliant(self._compliant_series.log(base=base))
+
+    def exp(self) -> Self:
+        r"""Compute the exponent.
+
+        Returns:
+            A new series.
+
+        Examples:
+            >>> import pandas as pd
+            >>> import narwhals as nw
+            >>> s_native = pd.Series([-1, 0, 1], name="a")
+            >>> s = nw.from_native(s_native, series_only=True)
+            >>> s.exp()
+            ┌───────────────────────┐
+            |    Narwhals Series    |
+            |-----------------------|
+            |0    0.367879          |
+            |1    1.000000          |
+            |2    2.718282          |
+            |Name: a, dtype: float64|
+            └───────────────────────┘
+        """
+        return self._with_compliant(self._compliant_series.exp())
+
+    def sqrt(self) -> Self:
+        r"""Compute the square root.
+
+        Returns:
+            A new series.
+
+        Examples:
+            >>> import pandas as pd
+            >>> import narwhals as nw
+            >>> s_native = pd.Series([1, 4, 9], name="a")
+            >>> s = nw.from_native(s_native, series_only=True)
+            >>> s.sqrt()
+            ┌───────────────────────┐
+            |    Narwhals Series    |
+            |-----------------------|
+            |0    1.0               |
+            |1    2.0               |
+            |2    3.0               |
+            |Name: a, dtype: float64|
+            └───────────────────────┘
+        """
+        return self._with_compliant(self._compliant_series.sqrt())
+
     @property
     def str(self) -> SeriesStringNamespace[Self]:
         return SeriesStringNamespace(self)
